summaryrefslogtreecommitdiffstats
path: root/kjsembed/jsobjecteventproxy.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/jsobjecteventproxy.h')
-rw-r--r--kjsembed/jsobjecteventproxy.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/kjsembed/jsobjecteventproxy.h b/kjsembed/jsobjecteventproxy.h
index de9f2e11..2ef662ae 100644
--- a/kjsembed/jsobjecteventproxy.h
+++ b/kjsembed/jsobjecteventproxy.h
@@ -22,8 +22,8 @@
#ifndef KJSEMBED_JSOBJECTEVENTPROXY_H
#define KJSEMBED_JSOBJECTEVENTPROXY_H
-#include <qbitarray.h>
-#include <qobject.h>
+#include <tqbitarray.h>
+#include <tqobject.h>
#include <kjs/object.h>
#include <global.h>
@@ -32,7 +32,7 @@ namespace KJSEmbed {
class JSObjectProxy;
/**
* Filters events for a QObject and forwards them to a JS handler.
*
* @version $Id$
* @author Richard Moore, rich@kde.org
@@ -46,26 +46,26 @@ public:
virtual ~JSObjectEventProxy();
/** Returns true iff we forward the event type to JS. */
- bool isFiltered( QEvent::Type t ) const;
+ bool isFiltered( TQEvent::Type t ) const;
/** Adds an event type to those we forward to JS. */
- void addFilter( QEvent::Type t );
+ void addFilter( TQEvent::Type t );
/**
* Removes an event type from those we forward to JS. If there are no
* event types left to forward then we self-destruct.
*/
- void removeFilter( QEvent::Type t );
+ void removeFilter( TQEvent::Type t );
/** Reimplemented to forward events to JS. */
- bool eventFilter ( QObject *watched, QEvent *e );
+ bool eventFilter ( TQObject *watched, TQEvent *e );
protected:
- KJS::Value callHandler( QEvent *e );
+ KJS::Value callHandler( TQEvent *e );
private:
JSObjectProxy *proxy;
- QBitArray eventMask;
+ TQBitArray eventMask;
uint refcount;
class JSObjectEventProxyPrivate *d;
};
@@ -32,7 +32,7 @@ namespace KJSEmbed {
class JSObjectProxy;
/**
- * Filters events for a QObject and forwards them to a JS handler.
+ * Filters events for a TQObject and forwards them to a JS handler.
*
* @version $Id$